Stan Math Library: stan/math/prim/scal/fun/ibeta.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
ibeta.hpp File Reference
`#include <boost/math/special_functions/beta.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
double | stan::math::ibeta (const double a, const double b, const double x)
| The normalized incomplete beta function of a, b, and x. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.